@@ -673,3 +673,24 @@ vcov_rq <- function(obj) {
     out <- summary(obj, cov = TRUE)$cov
     return(out)
 }
+
+#' Find odds ratios for coefficients and standard errors
+#' for glm.summary class objects
+#'
+#' @param obj a \code{glm.summary} class object
+#' @param label_mod_coef character string for how to modify the coefficient
+#' label.
+#' @param label_mod_se character string for how to modify the standard error
+#' label.
+
+or_summary <- function(obj, label_mod_coef = "(OR)",
+                        label_mod_se = "(OR)"){
+    if (class(obj) != "summary.glm")
+        stop("obj must be of summary.glm class.",
+             call. = FALSE)
+
+        obj$coefficients[, c(1, 2)] <- exp(obj$coefficients[, c(1, 2)])
+        colnames(obj$coefficients)[c(1, 2)] <- paste(
+                                colnames(obj$coefficients)[c(1, 2)], c(label_mod_coef, label_mod_se))
+        return(obj)
+}
